var searchData=
[
  ['has_5fcid_0',['has_cid',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#abf03386fd2cfaa59b3948645ad9ceb36',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5fsid_1',['has_sid',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a8415dcafcf5b32750a757b5b15424aad',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5ftime_5fspec_2',['has_time_spec',['../structuhd_1_1rx__metadata__t.html#a7cd978c6290c12f3bb92072286109123',1,'uhd::rx_metadata_t::has_time_spec'],['../structuhd_1_1tx__metadata__t.html#af8f34976fc468381bfc662f57a398360',1,'uhd::tx_metadata_t::has_time_spec'],['../structuhd_1_1async__metadata__t.html#a333d1558d0bf0621f4476fcab2e8a269',1,'uhd::async_metadata_t::has_time_spec']]],
  ['has_5ftlr_3',['has_tlr',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#aae2d1fc554402f5eda38879578af0add',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['has_5ftsf_4',['has_tsf',['../structuhd_1_1rfnoc_1_1tx__event__action__info.html#a7621de07341c51598b8a0954ec094ec3',1,'uhd::rfnoc::tx_event_action_info::has_tsf'],['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a05620235be16ac3b9ad1eaf0864d6627',1,'uhd::transport::vrt::if_packet_info_t::has_tsf']]],
  ['has_5ftsi_5',['has_tsi',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a9dcd8f46d3f39627945dd9d429fec8a3',1,'uhd::transport::vrt::if_packet_info_t']]]
];
